@@ -125,10 +125,53 @@ def render_url(query):
     return "https://query.wikidata.org/embed.html#" + urllib.parse.quote(query, safe="")
 
 
+def get_query_url_for_author_without_gender(info, mode="basic"):
+    query = (
+        """
+# title: Authors on Wikidata without a gender property
+SELECT
+  (SAMPLE(?number_of_works_) AS ?works)
+  (SAMPLE(?wikis_) AS ?wikis)
+  ?author ?authorLabel ?authorDescription
+  (SAMPLE(?orcid_) AS ?orcid)
+WITH {
+  SELECT DISTINCT ?author WHERE {
+"""
+        + get_selector(info, mode)
+        + """
+    
+    MINUS {?author wdt:P21 ?gender .}
+  } 
+} AS %authors
+WITH {
+  SELECT
+    (COUNT(?work) AS ?number_of_works_) ?author
+  WHERE {
+    INCLUDE %authors
+    OPTIONAL { ?work wdt:P50 ?author . }
+
+    # No biological pathways; they skew the statistics too much 
+    MINUS { ?work wdt:P31 wd:Q4915012 } 
+  } 
+  GROUP BY ?author
+} AS %authors_and_number_of_works
+WHERE {
+  INCLUDE %authors_and_number_of_works
+  OPTIONAL { ?author wdt:P496 ?orcid_ . }
+  OPTIONAL { ?author wikibase:sitelinks ?wikis_ }
+  SERVICE wikibase:label { bd:serviceParam wikibase:language "en,da,de,es,fr,nl,no,ru,sv,zh" . } 
+}
+GROUP BY ?author ?authorLabel ?authorDescription 
+ORDER BY DESC(?works)
+  """
+    )
+
+    return render_url(query)
+
+
 def get_query_url_for_author_without_affiliation(info, mode="basic"):
     query = (
         """
-# tool: scholia
 # title: Employees and affiliated with a specified organization
 SELECT
   (SAMPLE(?number_of_works_) AS ?works)
@@ -312,7 +355,7 @@ def get_topics_as_table(info, mode="basic"):
     INCLUDE %result
     SERVICE wikibase:label { bd:serviceParam wikibase:language "en,da,de,es,fr,jp,nl,no,ru,sv,zh" . } 
   }
-  ORDER BY DESC(?count) 
+  ORDER BY DESC(?n) 
 
   """
     )
